<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>SecStructPredictTask</name>
    <message>
        <location filename="../src/PsipredAlgTask.cpp" line="30"/>
        <source>psipred: sequence is too long, max seq size is 10000</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2</name>
    <message>
        <location filename="../src/PsipredAlgTask.cpp" line="14"/>
        <source>PsiPred</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::PsipredPlugin</name>
    <message>
        <location filename="../src/PsipredPlugin.cpp" line="34"/>
        <source>PsiPred</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/PsipredPlugin.cpp" line="34"/>
        <source>PsiPred protein secondary structure prediction</source>
        <translation type="unfinished">Предсказание вторичной структуры протеинов PsiPred</translation>
    </message>
</context>
</TS>
